@@ -30,15 +30,15 @@ VOCAB_FILES_NAMES = {"vocab_file": "sentencepiece.bpe.model"}
 
 PRETRAINED_VOCAB_FILES_MAP = {
     "vocab_file": {
-        "indobart": "https://huggingface.co/indobart/resolve/main/sentencepiece.bpe.model",
-        "indogpt": "https://huggingface.co/indogptresolve/main/sentencepiece.bpe.model",
-        "indobart-v2": "https://huggingface.co/indobart-v2/resolve/main/sentencepiece.bpe.model"
+        "indobenchmark/indobart": "https://huggingface.co/indobenchmark/indobart/resolve/main/sentencepiece.bpe.model",
+        "indobenchmark/indogpt": "https://huggingface.co/indobenchmark/indogpt/resolve/main/sentencepiece.bpe.model",
+        "indobenchmark/indobart-v2": "https://huggingface.co/indobenchmark/indobart-v2/resolve/main/sentencepiece.bpe.model"
     }
 }
 
 PRETRAINED_POSITIONAL_EMBEDDINGS_SIZES = {
     "indobenchmark/indobart": 768,
-    "ndobenchmark/indogpt": 768,
+    "indobenchmark/indogpt": 768,
     "indobenchmark/indobart-v2": 768
 }
 
@@ -161,6 +161,7 @@ class IndoNLGTokenizer(PreTrainedTokenizer):
             else:
                 raise ValueError(IndoNLGTokenizer.input_error_message)
         elif model_type == 'indobart':
+                                     
             # Process encoder input
             if lang_token not in self.special_tokens_to_ids:
                 raise ValueError(f"Unknown lang_token `{lang_token}`, lang_token must be either `[javanese]`, `[sundanese]`, or `[indonesian]`")  
@@ -173,9 +174,9 @@ class IndoNLGTokenizer(PreTrainedTokenizer):
             lang_id = self.special_tokens_to_ids[lang_token]
             input_batch = self(inputs, return_attention_mask=False)
             if type(inputs) == str:
-                input_batch['input_ids'] = [self.eos_token_id, lang_id] + input_batch['input_ids'] 
+                input_batch['input_ids'] = [self.bos_token_id] + input_batch['input_ids'] + [self.eos_token_id, lang_id]
             else:
-                input_batch['input_ids'] = list(map(lambda input_ids: input_ids + [self.eos_token_id, lang_id], input_batch['input_ids']))
+                input_batch['input_ids'] = list(map(lambda input_ids: [self.bos_token_id] + input_ids + [self.eos_token_id, lang_id], input_batch['input_ids']))
             
             if decoder_inputs is None:
                 # Return encoder input
@@ -196,10 +197,9 @@ class IndoNLGTokenizer(PreTrainedTokenizer):
                 decoder_input_batch = self(decoder_inputs, return_attention_mask=False)
                 
                 if type(decoder_inputs) == str:
-                    decoder_input_batch['input_ids'] = [lang_id] + decoder_input_batch['input_ids']  + [self.eos_token_id]
+                    decoder_input_batch['input_ids'] = [lang_id, self.bos_token_id] + decoder_input_batch['input_ids'] + [self.eos_token_id]
                 else:
-                    decoder_input_batch['input_ids'] = list(map(lambda input_ids: [lang_id] + input_ids + [self.eos_token_id], decoder_input_batch['input_ids']))
-                
+                    decoder_input_batch['input_ids'] = list(map(lambda input_ids: [lang_id, self.bos_token_id] + input_ids + [self.eos_token_id], decoder_input_batch['input_ids']))
                 # Padding
                 input_batch = self.pad(input_batch, return_tensors=return_tensors)
                 decoder_input_batch = self.pad(decoder_input_batch, return_tensors=return_tensors)
